cli

package
v0.0.0-...-ba2a1bf Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2026 License: MIT Imports: 68 Imported by: 0

README

CLI Developer Notes

This package contains technical consistency guidelines for CLI developers:

Document Description
help_style_guide.md Guidelines for consistent inline help formatting across all CLI commands
make_alias.md When to alias commands (and when not to)

Documentation

Overview

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file provides advanced commands that are useful for testing or development but not everyday use.

  • Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file provides aliases to frequently used commands that are inside other top level commands.

  • Copyright (c) 2021-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles CLI commands that pertain to AIS objects.

  • Copyright (c) 2021-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles commands that create entities in the cluster.

  • Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles specific bucket actions.

  • Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles commands that control running jobs in the cluster.

  • Copyright (c) 2024-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles CLI commands that pertain to AIS buckets.

  • Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2023-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles cluster and daemon operations.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains implementation of the top-level `show` command.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles download jobs in the cluster.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains error handlers and utilities.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles commands that control running jobs in the cluster.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains util functions and types.

  • Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles commands that control running jobs in the cluster.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains implementation of the top-level `show` command.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles CLI commands that pertain to AIS buckets.

  • Copyright (c) 2021-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles CLI commands that pertain to AIS objects.

  • Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.

  • Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.

  • Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains util functions and types.

  • Copyright (c) 2023-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles download jobs in the cluster.

  • Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file provides commands that remove various entities from the cluster.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains util functions and types.

  • Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles commands that control running jobs in the cluster.

  • Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains utility functions and types.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.

  • Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains utility functions and types.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2024-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains util functions and types.

  • Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.

Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.

  • Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.

Index

Constants

const (
	NIY = "not implemented yet" // TODO potentially
)

Variables

This section is empty.

Functions

func DamerauLevenstheinDistance

func DamerauLevenstheinDistance(s, t string) int

based on https://en.wikipedia.org/wiki/Damerau–Levenshtein_distance

func Init

func Init(args []string) (err error)

func Run

func Run(version, buildtime string, args []string) error

main method

func V

func V(err error) error

Types

type BackendDownloadJobDef

type BackendDownloadJobDef struct {
	// contains filtered or unexported fields
}

BackendDownloadJobDef handles backend downloads

func (*BackendDownloadJobDef) Start

func (j *BackendDownloadJobDef) Start(apiBP api.BaseParams) ([]string, error)

type DurationFlag

type DurationFlag cli.DurationFlag

func (DurationFlag) Apply

func (f DurationFlag) Apply(set *flag.FlagSet)

func (DurationFlag) ApplyWithError

func (f DurationFlag) ApplyWithError(set *flag.FlagSet) error

func (DurationFlag) GetName

func (f DurationFlag) GetName() string

func (DurationFlag) String

func (f DurationFlag) String() string

type DurationFlagVar

type DurationFlagVar cli.DurationFlag

func (*DurationFlagVar) Set

func (f *DurationFlagVar) Set(s string) (err error)

"s" (seconds) is the default time unit

func (DurationFlagVar) String

func (f DurationFlagVar) String() string

type HFDownloadJobDef

type HFDownloadJobDef struct {
	// contains filtered or unexported fields
}

HFDownloadJobDef handles HuggingFace repository downloads

func (*HFDownloadJobDef) Start

func (j *HFDownloadJobDef) Start(apiBP api.BaseParams) ([]string, error)

Start starts a HuggingFace Download job and the associated blob download jobs if requested

type JobDefinition

type JobDefinition interface {
	Start(apiBP api.BaseParams) ([]string, error) // Returns job IDs
}

type MultiDownloadJobDef

type MultiDownloadJobDef struct {
	// contains filtered or unexported fields
}

MultiDownloadJobDef handles file-list downloads

func (*MultiDownloadJobDef) Start

func (j *MultiDownloadJobDef) Start(apiBP api.BaseParams) ([]string, error)

type RangeDownloadJobDef

type RangeDownloadJobDef struct {
	// contains filtered or unexported fields
}

RangeDownloadJobDef handles range downloads

func (*RangeDownloadJobDef) Start

func (j *RangeDownloadJobDef) Start(apiBP api.BaseParams) ([]string, error)

type SingleDownloadJobDef

type SingleDownloadJobDef struct {
	// contains filtered or unexported fields
}

SingleDownloadJobDef handles single file downloads

func (*SingleDownloadJobDef) Start

func (j *SingleDownloadJobDef) Start(apiBP api.BaseParams) ([]string, error)

Jump to