Documentation
¶
Overview ¶
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file provides advanced commands that are useful for testing or development but not everyday use.
- Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file provides aliases to frequently used commands that are inside other top level commands.
- Copyright (c) 2021-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles CLI commands that pertain to AIS objects.
- Copyright (c) 2021-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles commands that create entities in the cluster.
- Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles specific bucket actions.
- Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles commands that control running jobs in the cluster.
- Copyright (c) 2024-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles CLI commands that pertain to AIS buckets.
- Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2023-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles cluster and daemon operations.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains implementation of the top-level `show` command.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles download jobs in the cluster.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains error handlers and utilities.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles commands that control running jobs in the cluster.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains util functions and types.
- Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles commands that control running jobs in the cluster.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains implementation of the top-level `show` command.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles CLI commands that pertain to AIS buckets.
- Copyright (c) 2021-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles CLI commands that pertain to AIS objects.
- Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.
- Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.
- Copyright (c) 2025-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains util functions and types.
- Copyright (c) 2023-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles download jobs in the cluster.
- Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file provides commands that remove various entities from the cluster.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains util functions and types.
- Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles commands that control running jobs in the cluster.
- Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains utility functions and types.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2021-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file handles object operations.
- Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains utility functions and types.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2024-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters. This file contains util functions and types.
- Copyright (c) 2018-2026, NVIDIA CORPORATION. All rights reserved.
Package cli provides easy-to-use commands to manage, monitor, and utilize AIS clusters.
- Copyright (c) 2018-2025, NVIDIA CORPORATION. All rights reserved.
Index ¶
- Constants
- func DamerauLevenstheinDistance(s, t string) int
- func Init(args []string) (err error)
- func Run(version, buildtime string, args []string) error
- func V(err error) error
- type BackendDownloadJobDef
- type DurationFlag
- type DurationFlagVar
- type HFDownloadJobDef
- type JobDefinition
- type MultiDownloadJobDef
- type RangeDownloadJobDef
- type SingleDownloadJobDef
Constants ¶
const (
NIY = "not implemented yet" // TODO potentially
)
Variables ¶
This section is empty.
Functions ¶
func DamerauLevenstheinDistance ¶
based on https://en.wikipedia.org/wiki/Damerau–Levenshtein_distance
Types ¶
type BackendDownloadJobDef ¶
type BackendDownloadJobDef struct {
// contains filtered or unexported fields
}
BackendDownloadJobDef handles backend downloads
func (*BackendDownloadJobDef) Start ¶
func (j *BackendDownloadJobDef) Start(apiBP api.BaseParams) ([]string, error)
type DurationFlag ¶
type DurationFlag cli.DurationFlag
func (DurationFlag) Apply ¶
func (f DurationFlag) Apply(set *flag.FlagSet)
func (DurationFlag) ApplyWithError ¶
func (f DurationFlag) ApplyWithError(set *flag.FlagSet) error
func (DurationFlag) GetName ¶
func (f DurationFlag) GetName() string
func (DurationFlag) String ¶
func (f DurationFlag) String() string
type DurationFlagVar ¶
type DurationFlagVar cli.DurationFlag
func (*DurationFlagVar) Set ¶
func (f *DurationFlagVar) Set(s string) (err error)
"s" (seconds) is the default time unit
func (DurationFlagVar) String ¶
func (f DurationFlagVar) String() string
type HFDownloadJobDef ¶
type HFDownloadJobDef struct {
// contains filtered or unexported fields
}
HFDownloadJobDef handles HuggingFace repository downloads
func (*HFDownloadJobDef) Start ¶
func (j *HFDownloadJobDef) Start(apiBP api.BaseParams) ([]string, error)
Start starts a HuggingFace Download job and the associated blob download jobs if requested
type JobDefinition ¶
type JobDefinition interface {
Start(apiBP api.BaseParams) ([]string, error) // Returns job IDs
}
type MultiDownloadJobDef ¶
type MultiDownloadJobDef struct {
// contains filtered or unexported fields
}
MultiDownloadJobDef handles file-list downloads
func (*MultiDownloadJobDef) Start ¶
func (j *MultiDownloadJobDef) Start(apiBP api.BaseParams) ([]string, error)
type RangeDownloadJobDef ¶
type RangeDownloadJobDef struct {
// contains filtered or unexported fields
}
RangeDownloadJobDef handles range downloads
func (*RangeDownloadJobDef) Start ¶
func (j *RangeDownloadJobDef) Start(apiBP api.BaseParams) ([]string, error)
type SingleDownloadJobDef ¶
type SingleDownloadJobDef struct {
// contains filtered or unexported fields
}
SingleDownloadJobDef handles single file downloads
func (*SingleDownloadJobDef) Start ¶
func (j *SingleDownloadJobDef) Start(apiBP api.BaseParams) ([]string, error)
Source Files
¶
- advanced_hdlr.go
- alias_hdlr.go
- app.go
- arch_hdlr.go
- auth_hdlr.go
- bencodeway_hdlr.go
- blob_hdlr.go
- bucket.go
- bucket_hdlr.go
- cluster_hdlr.go
- completions.go
- config_hdlr.go
- const.go
- cpr.go
- cpumem_show_hdlr.go
- daeclu.go
- disk.go
- downloader.go
- dsort.go
- err.go
- etl.go
- feat.go
- flag.go
- get.go
- help.go
- init.go
- io.go
- job_do_hdlr.go
- job_show_hdlr.go
- k8s_hdlr.go
- lhotse.go
- log_hdlr.go
- ls.go
- make_alias.go
- ml.go
- multiobj.go
- multipart.go
- multipart_hdlr.go
- nbi_hdlr.go
- object.go
- object_hdlr.go
- parse_uri.go
- performance.go
- progress.go
- reb_hdlr.go
- remcluster_hdlr.go
- scrub.go
- search_hdlr.go
- shard_idx_hdlr.go
- show_hdlr.go
- smap.go
- spec.go
- stats.go
- storage_hdlr.go
- strings.go
- tcbtco.go
- utils.go
- verbfobj.go
- version_check.go
- walk.go
- x509.go
- xact.go
- yap.go